epistasis\.models\.nonlinear package
====================================

epistasis\.models\.nonlinear\.ordinary module
---------------------------------------------

.. automodule:: epistasis.models.nonlinear.ordinary
    :members:
    :undoc-members:
    :show-inheritance:

epistasis\.models\.nonlinear\.power module
------------------------------------------

.. automodule:: epistasis.models.nonlinear.power
    :members:
    :undoc-members:
    :show-inheritance:
